@@ -39,7 +39,6 @@
 #include "cache_varnishd.h"
 #include "cache_director.h"
 
-#include "vsa.h"
 #include "vtcp.h"
 #include "vtim.h"
 #include "vsa.h"
@@ -636,7 +635,7 @@ via_endpoint(const struct vrt_endpoint *vep, const struct suckaddr *sa,
 	ret = VRT_Endpoint_Clone(nvep);
 	CHECK_OBJ_NOTNULL(ret, VRT_ENDPOINT_MAGIC);
 	VSB_destroy(&preamble);
-	free(nvep);
+	FREE_OBJ(nvep);
 
 	return (ret);
 }
