@@ -101,7 +101,7 @@ ved_reembark(struct worker *wrk, struct req *req)
 	CAST_OBJ_NOTNULL(ecx, req->transport_priv, ECX_MAGIC);
 	Lck_Lock(&req->sp->mtx);
 	ecx->woken = 1;
-	AZ(pthread_cond_signal(&ecx->preq->wrk->cond));
+	PTOK(pthread_cond_signal(&ecx->preq->wrk->cond));
 	Lck_Unlock(&req->sp->mtx);
 }
 
@@ -125,8 +125,10 @@ ved_include(struct req *preq, const char *src, const char *host,
 
 	if (preq->esi_level >= cache_param->max_esi_depth) {
 		VSLb(preq->vsl, SLT_VCL_Error,
-		    "ESI depth limit reach (param max_esi_depth = %u)",
+		    "ESI depth limit reached (param max_esi_depth = %u)",
 		    cache_param->max_esi_depth);
+		if (!ecx->incl_cont)
+			preq->top->topreq->vdc->retval = -1;
 		return;
 	}
 
@@ -202,7 +204,7 @@ ved_include(struct req *preq, const char *src, const char *host,
 		if (s == REQ_FSM_DONE)
 			break;
 		DSL(DBG_WAITINGLIST, req->vsl->wid,
-		    "loop waiting for ESI (%d)", (int)s);
+		    "waiting for ESI (%d)", (int)s);
 		assert(s == REQ_FSM_DISEMBARK);
 		Lck_Lock(&sp->mtx);
 		if (!ecx->woken)
@@ -310,7 +312,7 @@ static int v_matchproto_(vdp_bytes_f)
 ved_vdp_esi_bytes(struct vdp_ctx *vdx, enum vdp_action act, void **priv,
     const void *ptr, ssize_t len)
 {
-	uint8_t *q, *r;
+	const uint8_t *q, *r;
 	ssize_t l = 0;
 	uint32_t icrc = 0;
 	uint8_t tailbuf[8 + 5];
@@ -645,7 +647,7 @@ ved_gzgz_init(VRT_CTX, struct vdp_ctx *vdc, void **priv, struct objcore *oc)
  * in VDP_bytes(), but ved_bytes() covers it.
  *
  * To avoid unnecessary chunks downstream, it would be nice to re-structure the
- * code to intendify the last block, send VDP_END/VDP_FLUSH for that one and
+ * code to identify the last block, send VDP_END/VDP_FLUSH for that one and
  * VDP_NULL for anything before it.
  */
 
@@ -794,8 +796,7 @@ ved_gzgz_fini(struct vdp_ctx *vdc, void **priv)
 	struct ved_foo *foo;
 
 	(void)vdc;
-	CAST_OBJ_NOTNULL(foo, *priv, VED_FOO_MAGIC);
-	*priv = NULL;
+	TAKE_OBJ_NOTNULL(foo, priv, VED_FOO_MAGIC);
 
 	/* XXX
 	 * this works due to the esi layering, a VDP pushing bytes from _fini
@@ -856,6 +857,7 @@ ved_deliver(struct req *req, struct boc *boc, int wantbody)
 {
 	int i = 0;
 	const char *p;
+	uint16_t status;
 	struct ecx *ecx;
 	struct ved_foo foo[1];
 	struct vrt_ctx ctx[1];
@@ -869,9 +871,9 @@ ved_deliver(struct req *req, struct boc *boc, int wantbody)
 	if (wantbody == 0)
 		return;
 
-	if (!ecx->incl_cont &&
-	    req->resp->status != 200 &&
-	    req->resp->status != 204) {
+	status = req->resp->status % 1000;
+
+	if (!ecx->incl_cont && status != 200 && status != 204) {
 		req->top->topreq->vdc->retval = -1;
 		req->top->topreq->doclose = req->doclose;
 		return;
@@ -924,7 +926,7 @@ ved_deliver(struct req *req, struct boc *boc, int wantbody)
 	if (i && req->doclose == SC_NULL)
 		req->doclose = SC_REM_CLOSE;
 
-	req->acct.resp_bodybytes += VDP_Close(req->vdc);
+	req->acct.resp_bodybytes += VDP_Close(req->vdc, req->objcore, boc);
 
 	if (i && !ecx->incl_cont) {
 		req->top->topreq->vdc->retval = -1;
