@@ -152,8 +152,8 @@ Resp_Setup_Deliver(struct req *req)
 	http_ForceField(h, HTTP_HDR_PROTO, "HTTP/1.1");
 
 	if (req->is_hit)
-		http_PrintfHeader(h, "X-Varnish: %ju %u", VXID(req->vsl->wid),
-		    ObjGetXID(req->wrk, oc));
+		http_PrintfHeader(h, "X-Varnish: %ju %ju", VXID(req->vsl->wid),
+		    VXID(ObjGetXID(req->wrk, oc)));
 	else
 		http_PrintfHeader(h, "X-Varnish: %ju", VXID(req->vsl->wid));
 
@@ -488,14 +488,15 @@ cnt_transmit(struct worker *wrk, struct req *req)
 
 	VSLb_ts_req(req, "Resp", W_TIM_real(wrk));
 
-	HSH_Cancel(wrk, req->objcore, boc);
-
 	if (req->doclose == SC_NULL && (req->objcore->flags & OC_F_FAILED)) {
 		/* The object we delivered failed due to a streaming error.
 		 * Fail the request. */
 		req->doclose = SC_TX_ERROR;
 	}
 
+	if (req->doclose != SC_NULL)
+		req->acct.resp_bodybytes += VDP_Close(req->vdc, req->objcore, boc);
+
 	if (boc != NULL)
 		HSH_DerefBoc(wrk, req->objcore);
 
@@ -888,6 +889,7 @@ cnt_recv_prep(struct req *req, const char *ci)
 		req->hash_ignore_vary = 0;
 		req->client_identity = NULL;
 		req->storage = NULL;
+		req->trace = FEATURE(FEATURE_TRACE);
 	}
 
 	req->is_hit = 0;
