@@ -315,20 +315,20 @@ term_expect_text(struct process *pp,
 	l = strlen(pat);
 	if (x + l - 1 > pp->ncol)
 		vtc_fatal(pp->vl, "XXX %d ncol %d", x + l - 1, pp->ncol);
-	AZ(pthread_mutex_lock(&pp->mtx));
+	PTOK(pthread_mutex_lock(&pp->mtx));
 	while (!term_find_text(pp, &x, &y, pat)) {
 		if (x != 0 && y != 0) {
 			t = pp->vram[y - 1] + x - 1;
 			vtc_log(pp->vl, 4,
 			    "text at %d,%d: '%.*s'", y, x, l, t);
 		}
-		AZ(pthread_mutex_unlock(&pp->mtx));
+		PTOK(pthread_mutex_unlock(&pp->mtx));
 		usleep(d);
-		AZ(pthread_mutex_lock(&pp->mtx));
+		PTOK(pthread_mutex_lock(&pp->mtx));
 		if (d < 3000000)
 			d += d;
 	}
-	AZ(pthread_mutex_unlock(&pp->mtx));
+	PTOK(pthread_mutex_unlock(&pp->mtx));
 	vtc_log(pp->vl, 4, "found expected text at %d,%d: '%s'", y, x, pat);
 }
 
@@ -394,7 +394,7 @@ term_match_text(struct process *pp,
 		    re, erroff, errbuf);
 	}
 
-	AZ(pthread_mutex_lock(&pp->mtx));
+	PTOK(pthread_mutex_lock(&pp->mtx));
 
 	len = (pp->nlin - y) * (pp->ncol - x);
 	for (i = y; i < pp->nlin; i++) {
@@ -409,7 +409,7 @@ term_match_text(struct process *pp,
 	else
 		vtc_log(pp->vl, 4, "match succeeded");
 
-	AZ(pthread_mutex_unlock(&pp->mtx));
+	PTOK(pthread_mutex_unlock(&pp->mtx));
 	VSB_destroy(&vsb);
 	VRE_free(&vre);
 }
@@ -461,7 +461,7 @@ process_new(const char *name)
 	ALLOC_OBJ(p, PROCESS_MAGIC);
 	AN(p);
 	REPLACE(p->name, name);
-	AZ(pthread_mutex_init(&p->mtx, NULL));
+	PTOK(pthread_mutex_init(&p->mtx, NULL));
 
 	p->vl = vtc_logopen("%s", name);
 	AN(p->vl);
@@ -495,7 +495,7 @@ process_delete(struct process *p)
 	int i;
 
 	CHECK_OBJ_NOTNULL(p, PROCESS_MAGIC);
-	AZ(pthread_mutex_destroy(&p->mtx));
+	PTOK(pthread_mutex_destroy(&p->mtx));
 	vtc_logclose(p->vl);
 	free(p->name);
 	free(p->dir);
@@ -554,9 +554,9 @@ process_stdout(const struct vev *ev, int what)
 		vtc_log(p->vl, 4, "stdout read %d", i);
 		return (1);
 	}
-	AZ(pthread_mutex_lock(&p->mtx));
+	PTOK(pthread_mutex_lock(&p->mtx));
 	p->stdout_bytes += i;
-	AZ(pthread_mutex_unlock(&p->mtx));
+	PTOK(pthread_mutex_unlock(&p->mtx));
 	if (p->log == 1)
 		(void)VLU_Feed(p->vlu_stdout, buf, i);
 	else if (p->log == 2)
@@ -564,9 +564,9 @@ process_stdout(const struct vev *ev, int what)
 	else if (p->log == 3)
 		vtc_hexdump(p->vl, 4, "stdout", buf, i);
 	assert(write(p->f_stdout, buf, i) == i);
-	AZ(pthread_mutex_lock(&p->mtx));
+	PTOK(pthread_mutex_lock(&p->mtx));
 	teken_input(p->tek, buf, i);
-	AZ(pthread_mutex_unlock(&p->mtx));
+	PTOK(pthread_mutex_unlock(&p->mtx));
 	return (0);
 }
 
@@ -584,9 +584,9 @@ process_stderr(const struct vev *ev, int what)
 		vtc_log(p->vl, 4, "stderr read %d", i);
 		return (1);
 	}
-	AZ(pthread_mutex_lock(&p->mtx));
+	PTOK(pthread_mutex_lock(&p->mtx));
 	p->stderr_bytes += i;
-	AZ(pthread_mutex_unlock(&p->mtx));
+	PTOK(pthread_mutex_unlock(&p->mtx));
 	vtc_dump(p->vl, 4, "stderr", buf, i);
 	assert(write(p->f_stderr, buf, i) == i);
 	return (0);
@@ -654,13 +654,13 @@ process_thread(void *priv)
 	closefd(&p->f_stdout);
 	closefd(&p->f_stderr);
 
-	AZ(pthread_mutex_lock(&p->mtx));
+	PTOK(pthread_mutex_lock(&p->mtx));
 
 	/* NB: We keep the other macros around */
 	macro_undef(p->vl, p->name, "pid");
 	p->pid = -1;
 
-	AZ(pthread_mutex_unlock(&p->mtx));
+	PTOK(pthread_mutex_unlock(&p->mtx));
 
 	pthread_cleanup_pop(0);
 	VEV_Destroy(&evb);
@@ -787,7 +787,7 @@ process_start(struct process *p)
 	macro_def(p->vl, p->name, "out", "%s", p->out);
 	macro_def(p->vl, p->name, "err", "%s", p->err);
 	p->hasthread = 1;
-	AZ(pthread_create(&p->tp, NULL, process_thread, p));
+	PTOK(pthread_create(&p->tp, NULL, process_thread, p));
 }
 
 /**********************************************************************
@@ -800,7 +800,7 @@ process_wait(struct process *p)
 	void *v;
 
 	if (p->hasthread) {
-		AZ(pthread_join(p->tp, &v));
+		PTOK(pthread_join(p->tp, &v));
 		p->hasthread = 0;
 	}
 	vtc_log(p->vl, 4, "stdout %ju bytes, stderr %ju bytes",
@@ -820,9 +820,9 @@ process_kill(struct process *p, const char *sig)
 	CHECK_OBJ_NOTNULL(p, PROCESS_MAGIC);
 	AN(sig);
 
-	AZ(pthread_mutex_lock(&p->mtx));
+	PTOK(pthread_mutex_lock(&p->mtx));
 	pid = p->pid;
-	AZ(pthread_mutex_unlock(&p->mtx));
+	PTOK(pthread_mutex_unlock(&p->mtx));
 
 	if (pid <= 0)
 		vtc_fatal(p->vl, "Cannot signal a non-running process");
@@ -908,10 +908,14 @@ process_close(struct process *p)
  * Output from the stderr-pipe is copied verbatim to ${pNAME_err}, and
  * is always included in the vtc_log.
  *
- *	process pNAME SPEC [-log] [-dump] [-hexdump] [-expect-exit N]
- *		[-start] [-run]
- *		[-write STRING] [-writeln STRING]
- *		[-kill STRING] [-stop] [-wait] [-close]
+ *	process pNAME SPEC [-allow-core] [-expect-exit N] [-expect-signal N]
+ *		[-dump] [-hexdump] [-log]
+ *		[-run] [-close] [-kill SIGNAL] [-start] [-stop] [-wait]
+ *		[-write STRING] [-writeln STRING] [-writehex HEXSTRING]
+ *		[-need-bytes [+]NUMBER]
+ *		[-screen-dump] [-winsz LINES COLUMNSS] [-ansi-response]
+ *		[-expect-cursor LINE COLUMN] [-expect-text LINE COLUMN TEXT]
+ *		[-match-text LINE COLUMN REGEXP]
  *
  * pNAME
  *	Name of the process. It must start with 'p'.
@@ -934,6 +938,12 @@ process_close(struct process *p)
  * \-expect-exit N
  *	Expect exit status N
  *
+ * \-expect-signal N
+ *	Expect signal in exit status N
+ *
+ * \-allow-core
+ *	Core dump in exit status is OK
+ *
  * \-wait
  *	Wait for the process to finish.
  *
@@ -954,7 +964,12 @@ process_close(struct process *p)
  *	expression from either output, consider using it if you only need
  *	to match one.
  *
- * \-kill STRING
+ * \-key KEYSYM
+ *      Send emulated key-press.
+ *      KEYSYM can be one of (NPAGE, PPAGE, HOME, END)
+ *
+ *
+ * \-kill SIGNAL
  *	Send a signal to the process. The argument can be either
  *	the string "TERM", "INT", or "KILL" for SIGTERM, SIGINT or SIGKILL
  *	signals, respectively, or a hyphen (-) followed by the signal
@@ -970,7 +985,10 @@ process_close(struct process *p)
  * \-stop
  *	Shorthand for -kill TERM.
  *
- * \-winsz LIN COL
+ * \-close
+ *	Alias for "-kill HUP"
+ *
+ * \-winsz LINES COLUMNS
  *	Change the terminal window size to LIN lines and COL columns.
  *
  * \-write STRING
@@ -986,22 +1004,26 @@ process_close(struct process *p)
  *	Wait until at least NUMBER bytes have been received in total.
  *	If '+' is prefixed, NUMBER new bytes must be received.
  *
- * \-expect-text LIN COL PAT
- *	Wait for PAT to appear at LIN,COL on the virtual screen.
+ * \-ansi-response
+ *	Respond to terminal respond-back sequences
+ *
+ * \-expect-cursor LINE COLUMN
+ *	Expect cursors location
+ *
+ * \-expect-text LINE COLUMNS TEXT
+ *	Wait for TEXT to appear at LIN,COL on the virtual screen.
  *	Lines and columns are numbered 1...N
  *	LIN==0 means "on any line"
  *	COL==0 means "anywhere on the line"
  *
- * \-match-text LIN COL PAT
+ * \-match-text LINE COLUMN REGEXP
  *	Wait for the PAT regular expression to match the text at LIN,COL on the virtual screen.
  *	Lines and columns are numbered 1...N
  *	LIN==0 means "on any line"
  *	COL==0 means "anywhere on the line"
  *
- * \-close
- *	Alias for "-kill HUP"
  *
- * \-screen_dump
+ * \-screen-dump
  *	Dump the virtual screen into vtc_log
  *
  */
@@ -1083,6 +1105,19 @@ cmd_process(CMD_ARGS)
 			p->log = 3;
 			continue;
 		}
+		if (!strcmp(*av, "-key")) {
+			if (!strcmp(av[1], "NPAGE"))
+				process_write(p, "\x1b\x5b\x36\x7e");
+			else if (!strcmp(av[1], "PPAGE"))
+				process_write(p, "\x1b\x5b\x35\x7e");
+			else if (!strcmp(av[1], "HOME"))
+				process_write(p, "\x1b\x4f\x48");
+			else if (!strcmp(av[1], "END"))
+				process_write(p, "\x1b\x4f\x46");
+			else
+				vtc_fatal(p->vl, "Unknown key %s", av[1]);
+			continue;
+		}
 		if (!strcmp(*av, "-kill")) {
 			process_kill(p, av[1]);
 			av++;
@@ -1101,9 +1136,9 @@ cmd_process(CMD_ARGS)
 				u += bsnap;
 			av++;
 			do {
-				AZ(pthread_mutex_lock(&p->mtx));
+				PTOK(pthread_mutex_lock(&p->mtx));
 				v = p->stdout_bytes;
-				AZ(pthread_mutex_unlock(&p->mtx));
+				PTOK(pthread_mutex_unlock(&p->mtx));
 				vtc_log(p->vl, 4, "Have %ju bytes", v);
 				usleep(500000);
 			} while(v < u);
@@ -1165,9 +1200,9 @@ cmd_process(CMD_ARGS)
 			col = atoi(av[2]);
 			assert(col > 1);
 			av += 2;
-			AZ(pthread_mutex_lock(&p->mtx));
+			PTOK(pthread_mutex_lock(&p->mtx));
 			term_resize(p, lin, col);
-			AZ(pthread_mutex_unlock(&p->mtx));
+			PTOK(pthread_mutex_unlock(&p->mtx));
 			process_winsz(p, p->fd_term);
 			continue;
 		}
